Struct rusoto_elastictranscoder::TestRoleResponse
[−]
[src]
pub struct TestRoleResponse {
pub messages: Option<ExceptionMessages>,
pub success: Option<Success>,
}The TestRoleResponse structure.
Fields
messages: Option<ExceptionMessages>
If the Success element contains false, this value is an array of one or more error messages that were generated during the test process.
success: Option<Success>
If the operation is successful, this value is true; otherwise, the value is false.